==> snort-1.6.3.tar.gz: SnortSnarf-062000.1/sisr/cgi/sel_to_add.pl <==
#!/usr/bin/perl

# sel_to_add.pl, distributed as part of Snortsnarf v062000.1
# Author: James Hoagland, Silicon Defense (hoagland@SiliconDefense.com)
# copyright (c) 2000 by Silicon Defense (http://www.silicondefense.com/)
# Released under GNU General Public License, see the COPYING file included
# with the distribution or http://www.silicondefense.com/snortsnarf/ for
# details.

# sel_to_add.pl is a CGI script that accepts a SISR configuration file in
#   the field 'configfile', an ip address in 'ip', an end ('src' or 'dest')
#   in 'end', a comma-separated list of logs in 'logs' to produce a HTML
#   form for selecting a portion of the alerts with 'end' 'ip' in 'logs' to
#   add to a labeled alert set.

# Please send complaints, kudos, and especially improvements and bugfixes to
# hoagland@SiliconDefense.com.  As described in GNU General Public License, no
# warranty is expressed for this program.

use CGI;
require "snort_alert_parse.pl";
require "sisr_utils.pl";

# get paramaters of the invocation
$input= new CGI;
foreach (@ARGV) {  # simulate field input if running on command line
  $input->param(split('=',$_,2));
}
$configfile= $input->param('configfile');
$end= $input->param('end');
$ip= $input->param('ip');
$logs= $input->param('logs');
@logs= split(',',$logs);

# print out headers
print $input->header(-header => 'text/html',-expires => '+0d');

($setfile,$modpath,$defaultname)= &get_config_fields($configfile);

@alerts= ();
$filehandle= 'fh00';
foreach $log (@logs) {
	if($log =~ /scan/) {
		$file_type = 'scan';
	} elsif($log =~ /syslog/) {
		$file_type = 'syslog';
  	} elsif($log =~ /messages/) {
		$file_type = 'syslog';
	} else {
		$file_type = 'alert';
	}
   
	my $fh= $filehandle++;
	open($fh,"<$log") || die "could not open log \"$log\" for reading";
	$count= 0;
	while (1) {
		($alert_text,$format)= &next_alert($fh,$file_type);
		last unless defined($alert_text);
		$count++;
		#print "$alert_text<BR>\n";
		if (($end eq 'src' && $alert_text =~ /$ip(|:\d+)\s+->/) || ($end eq 'dest' && $alert_text =~ /->\s+$ip/)) {
			$alert_text =~ s/\s+$//;
			push(@alerts,[$alert_text,$count,$log,$file_type]);
		}
	}
	close $fh;
}

print "<HTML><HEAD><TITLE>Add alerts with ",($end eq 'src'?'source':'destination')," $ip</TITLE></HEAD>\n";

($setfile_filename)= &filename($setfile);
print <<">>";
<BODY bgcolor="#E7DEBD">
<H1>Add alerts to a labelled set in $setfile_filename</H1>
Choose the alerts you wish to add to a labelled set and give the set name.  If the set does not already exist, it will be created.<P>
>>

&pipeline_form_start("setifempty2.pl allalertlocs=\$alertlocs | extr_alerts.pl \$allalertlocs file_info_ \%alerts | config_alert_set_db.pl $configfile \$setfile | add_alerts_to_db_set.pl \%alerts \$setname \$setfile| lab_set_view.pl \$setname \$setfile",$modpath);

@allalertlocs=();
foreach $alertinfo (@alerts) {
	my($alert,$num,$filepath,$format)= @{$alertinfo};
	my($file)= &filename($filepath);
	push(@allalertlocs,$file.":$num");
}
$allalertlocs= join(';',@allalertlocs);

print <<">>";

<INPUT TYPE="checkbox" NAME="allalertlocs" VALUE="$allalertlocs" CHECKED></TD> Select all alerts<BR>
<B>-or-</B>
<TABLE BORDER=3>
	<TR>
		<TH>&nbsp;</TH>
		<TH>Alert text</TH>
		<TH>From</TH>
	</TR>
>>

$later='';
%fileinfo=();
foreach $alertinfo (@alerts) {
	my($alert,$num,$filepath,$format)= @{$alertinfo};
	$alert =~ s/[\n\r]+/<br>/g;
	
	my($file)= &filename($filepath);
	$fileinfo{$file}= [$format,$filepath];
		
	my $alertloc="$file:$num";
	print <<">>"
	<TR>
		<TD ALIGN=right><INPUT TYPE="checkbox" NAME="alertlocs" VALUE="$alertloc"></TD>
		<TD ALIGN=left><code>$alert</code></TD>
		<TD ALIGN=CENTER>$file #$num</TD>
	</TR>
>>
}

print <<">>";
</TABLE>
Add to set: <INPUT TYPE="text" NAME="setname" VALUE="$defaultname" SIZE="20"><INPUT TYPE="submit" VALUE="Add/Create"> in $setfile

<INPUT TYPE=hidden NAME="configfile" VALUE="$configfile">
>>
print join("\n",map("<INPUT TYPE=hidden NAME=\"file_info_$_\" VALUE=\"".join(',',@{$fileinfo{$_}})."\">",keys %fileinfo)),"\n";

print <<">>";

</FORM>
<P>
<BR>
Generated by <EM>$0</EM> from <EM>$logs</EM>, grabbing <EM>$end $ip</EM>
</BODY>
</HTML>
>>

sub get_config_fields {
	my($configfile)= shift;
	open(C,"<$configfile") || die "could not open config file \"$configfile\"";
	my($setfile,$modpath,$setname);
	$setfile= $modpath= undef;
	$setname= '';
	while (<C>) {
		if (s/^set-db-loc\s*:\s*//) {
			s/\s+$//;
			$setfile= $_;
			next;
		}
		if (s/^module-path\s*:\s*//) {
			s/\s+$//;
			$modpath= $_;
			next;
		}
		if (s/^set-name-default\s*:\s*//) {
			s/\s+$//;
			$setname= $_;
		}
	}
	close C;
	defined($setfile) || die "could not find labeled set database file \"set-db-loc\" in $configfile";
	defined($modpath) || die "could not find pipeline module path \"module-path\" in $configfile";
	
	if ($setname =~ m:^/:) { # get name from file
		my $namefile= $setname;
		open(F,"<$namefile") || die "could not open $namefile (set-name-default in $configfile) to get default set name from";
		do { $_= <F> } while (/^#/ || /^\s*$/);
		chomp;
		$setname= $_;
		close F;
		my $nextname= $setname;
		if ($nextname =~ s/(\d+)$//) { # should update count in file
			$nextname.= ($1 + 1); # update trailing number part of set name
			if (open(F,">$namefile")) {
				print F "# this is the next default set name:\n$nextname\n";
				close F;
			} else {
				warn "could not update default set name from $setname to $nextname since could not write to file $namefile";
			}
		}
	}
	return ($setfile,$modpath,$setname);
}

sub filename {
	return $_[0] =~ /([^\/]+)$/;
}

1;

# $Id: sel_to_add.pl,v 1.3 2000/06/21 00:32:30 jim Exp $

==> snort-1.7.tar.gz: SnortSnarf-111500.1/sisr/cgi/sel_to_add.pl <==
#!/usr/bin/perl

# sel_to_add.pl, distributed as part of Snortsnarf v111500.1
# Author: James Hoagland, Silicon Defense (hoagland@SiliconDefense.com)
# copyright (c) 2000 by Silicon Defense (http://www.silicondefense.com/)
# Released under GNU General Public License, see the COPYING file included
# with the distribution or http://www.silicondefense.com/snortsnarf/ for
# details.

# sel_to_add.pl is a CGI script that accepts a SISR configuration file in
#   the field 'configfile', an ip address in 'ip', an end ('src' or 'dest')
#   in 'end', a comma-separated list of logs in 'logs' to produce a HTML
#   form for selecting a portion of the alerts with 'end' 'ip' in 'logs' to
#   add to a labeled alert set.

# Please send complaints, kudos, and especially improvements and bugfixes to
# hoagland@SiliconDefense.com.  As described in GNU General Public License, no
# warranty is expressed for this program.

use CGI;
require "snort_alert_parse.pl";
require "sisr_utils.pl";

# get paramaters of the invocation
$input= new CGI;
foreach (@ARGV) {  # simulate field input if running on command line
  $input->param(split('=',$_,2));
}
$configfile= $input->param('configfile');
$end= $input->param('end');
$ip= $input->param('ip');
$logs= $input->param('logs');
$include= $input->param('include');
@logs= split(',',$logs);

# print out headers
print $input->header(-header => 'text/html',-expires => '+0d');

($setfile,$modpath,$defaultname)= &get_config_fields($configfile);

@alerts= &grab_alerts_of_type($ip,$end,$include,@logs);

print "<HTML><HEAD><TITLE>Add alerts with ",($end eq 'src'?'source':'destination')," $ip</TITLE></HEAD>\n";

($setfile_filename)= &filename($setfile);
print <<">>";
<BODY bgcolor="#E7DEBD">
<H1>Add alerts to a labelled set in $setfile_filename</H1>
Choose the alerts you wish to add to a labelled set and give the set name.  If the set does not already exist, it will be created.<P>
>>

&pipeline_form_start("setifempty2.pl allalertlocs=\$alertlocs | extr_alerts.pl \$allalertlocs file_info_ \%alerts | add_alerts_to_db_set.pl \%alerts \$setname $setfile| add_alert_set_notes_to_anns.pl \%alerts \$setname $setfile| lab_set_view.pl \$setname $setfile",$modpath);

@allalertlocs=();
foreach $alertinfo (@alerts) {
	my($alert,$num,$filepath,$file_type,$format)= @{$alertinfo};
	my($file)= &filename($filepath);
	push(@allalertlocs,$file.":$num");
}
$allalertlocs= join(';',@allalertlocs);

print <<">>";

<INPUT TYPE="checkbox" NAME="allalertlocs" VALUE="$allalertlocs" CHECKED></TD> Select all alerts<BR>
<B>-or-</B>
<TABLE BORDER=3>
	<TR>
		<TH>&nbsp;</TH>
		<TH>Alert text</TH>
		<TH>From</TH>
	</TR>
>>

%fileinfo=();
foreach $alertinfo (@alerts) {
	my($alert,$num,$filepath,$file_type,$format)= @{$alertinfo};
	$alert =~ s/[\n\r]+/<br>/g;
	
	my($file)= &filename($filepath);
	$fileinfo{$file}= [$file_type,$filepath];
		
	my $alertloc="$file:$num";
	print <<">>"
	<TR>
		<TD ALIGN=right><INPUT TYPE="checkbox" NAME="alertlocs" VALUE="$alertloc" CHECKED></TD>
		<TD ALIGN=left><code>$alert</code></TD>
		<TD ALIGN=CENTER>$file #$num</TD>
	</TR>
>>
}

print <<">>";
</TABLE>
Add to set: <INPUT TYPE="text" NAME="setname" VALUE="$defaultname" SIZE="20"><INPUT TYPE="submit" VALUE="Add/Create"> in $setfile

<INPUT TYPE=hidden NAME="configfile" VALUE="$configfile">
>>
print join("\n",map("<INPUT TYPE=hidden NAME=\"file_info_$_\" VALUE=\"".join(',',@{$fileinfo{$_}})."\">",keys %fileinfo)),"\n";

@sel= ();
push(@sel,'general') if $include =~ /g/;
push(@sel,'anomaly reports') if $include =~ /a/;
$sel= join(',',@sel);
print <<">>";

</FORM>
<P>
<BR>
Generated by <EM>$0</EM> from <EM>$logs</EM>, grabbing <EM>$end $ip</EM> and selecting <EM>{$sel}</EM>
</BODY>
</HTML>
>>

sub get_config_fields {
	my($configfile)= shift;
	open(C,"<$configfile") || die "could not open config file \"$configfile\"";
	my($setfile,$modpath,$setname);
	$setfile= $modpath= undef;
	$setname= '';
	while (<C>) {
		if (s/^set-db-loc\s*:\s*//) {
			s/\s+$//;
			$setfile= $_;
			next;
		}
		if (s/^module-path\s*:\s*//) {
			s/\s+$//;
			$modpath= $_;
			next;
		}
		if (s/^set-name-default\s*:\s*//) {
			s/\s+$//;
			$setname= $_;
		}
	}
	close C;
	defined($setfile) || die "could not find labeled set database file \"set-db-loc\" in $configfile";
	defined($modpath) || die "could not find pipeline module path \"module-path\" in $configfile";
	
	if ($setname =~ m:^/:) { # get name from file
		my $namefile= $setname;
		open(F,"<$namefile") || die "could not open $namefile (set-name-default in $configfile) to get default set name from";
		do { $_= <F> } while (defined($_) && /^#/ || /^\s*$/);
		$_= "no-setname-found-in-$namefile" unless defined($_);
		chomp;
		$setname= $_;
		close F;
		my $nextname= $setname;
		if ($nextname =~ s/(\d+)$//) { # should update count in file
			$nextname.= ($1 + 1); # update trailing number part of set name
			if (open(F,">$namefile")) {
				print F "# this is the next default set name:\n$nextname\n";
				close F;
			} else {
				warn "could not update default set name from $setname to $nextname since could not write to file $namefile";
			}
		}
	}
	return ($setfile,$modpath,$setname);
}

sub filename {
	return $_[0] =~ /([^\/]+)$/;
}

1;

# $Id: sel_to_add.pl,v 1.13 2000/11/15 22:40:28 jim Exp $
